<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de">
<defaultcodec></defaultcodec>
<context>
    <name>CBoatElementWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Information des Segels</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="145"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="146"/>
        <source>name</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="147"/>
        <source>Reload</source>
        <translation>neu laden</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="148"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="149"/>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="144"/>
        <source>Element information</source>
        <translation>Elementeinformationen</translation>
    </message>
</context>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation type="obsolete">Öffnen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Speichern</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>There was an error writing to the selected file.</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="88"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="110"/>
        <source>There was an error reading from the selected file.</source>
        <translation>Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="127"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>CFormBoat</name>
    <message>
        <location filename="../formboat.cpp" line="104"/>
        <source>boat</source>
        <translation>Boot</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="105"/>
        <source>&amp;Add</source>
        <translation>&amp;beitragen</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="106"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="167"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>CFormHull</name>
    <message>
        <location filename="../formhull.cpp" line="57"/>
        <source>hull</source>
        <translation>Rumpf</translation>
    </message>
    <message>
        <location filename="../formhull.cpp" line="58"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
</context>
<context>
    <name>CFormHullDefBase</name>
    <message>
        <location filename="../formhulldefbase.ui" line="20"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="86"/>
        <source>Deck and bottom</source>
        <translation>Deck und Rumpf</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="104"/>
        <source>Planking</source>
        <translation>Beplankung</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="116"/>
        <source>Automatic planking</source>
        <translation>Automatische Beplankung</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="167"/>
        <source>lower plank angle</source>
        <translation>Unterer Plankenwinkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="231"/>
        <source>top plank angle</source>
        <translation>Oberer Plankenwinkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="238"/>
        <source>Number of planks</source>
        <translation>Anzahl der Planken</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="256"/>
        <source>Bottom</source>
        <translation>Boden</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="313"/>
        <source>Bottom sweep angle</source>
        <translation>Unterer Anstellwinkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="334"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="446"/>
        <source>Max Width</source>
        <translation>Max. Breite</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="655"/>
        <source>Forward shape</source>
        <translation>Bug-Form</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="662"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="677"/>
        <source>Forward height </source>
        <translation>Bug-Höhe</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="684"/>
        <source>Max Width position</source>
        <translation>Position max. Breite</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="706"/>
        <source>Stem angle</source>
        <translation>Vorsteven-Winkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="713"/>
        <source>Transom angle</source>
        <translation>Heckspiegel-Winkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1752"/>
        <source>Aft height</source>
        <translation>Heck-Höhe</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="735"/>
        <source>Aft width</source>
        <translation>Heck-Breite</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="742"/>
        <source>Aft shape</source>
        <translation>Heckform</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="794"/>
        <source>Hull name</source>
        <translation>Rumpfname</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="804"/>
        <source>Deck</source>
        <translation>Deck</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1745"/>
        <source>Forward height</source>
        <translation>Bug-Höhe</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1068"/>
        <source>Plank 5</source>
        <translation>Planke 5</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1773"/>
        <source>Chine angle</source>
        <translation type="unfinished">Unterer Rumpf-Winkel??</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1766"/>
        <source>Sweep angle</source>
        <translation>Kiel-Winkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1759"/>
        <source>Plank angle</source>
        <translation>Plankenwinkel</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1211"/>
        <source>Plank 4</source>
        <translation>Planke 4</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1354"/>
        <source>Plank 3</source>
        <translation>Planke 3</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1640"/>
        <source>Plank 2</source>
        <translation>Planke 2</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1497"/>
        <source>Plank 1</source>
        <translation>Planke 1</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="925"/>
        <source>Plank 6</source>
        <translation>Planke 6</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="53"/>
        <source>Check</source>
        <translation>Prüfen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="60"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="67"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1826"/>
        <source>Dimensions are in millimeters and angles in degrees measured from horizontal</source>
        <translation>Alle Massangaben sind in Millimeter und Grad zur Horizontalen</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="913"/>
        <source>Planks</source>
        <translation>Planken</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="439"/>
        <source>txt_BBW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="467"/>
        <source>txt_BfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="488"/>
        <source>txt_BLWL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="509"/>
        <source>txt_BaftW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="603"/>
        <source>txt_BaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="648"/>
        <source>Dead rise angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="773"/>
        <source>txt_HullID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="860"/>
        <source>txt_DaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="881"/>
        <source>txt_DfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="895"/>
        <source>Side angle</source>
        <translation>Seitenwinkel</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation type="obsolete">&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation type="obsolete">&amp;TXT Segel</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation type="obsolete">&amp;XML Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="124"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="129"/>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="131"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="132"/>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="134"/>
        <source>&amp;Quit</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation type="obsolete">&amp;Abmessungen</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation type="obsolete">&amp;Form</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation type="obsolete">&amp;Verstärkungen</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation type="obsolete">&amp;Rigg</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="122"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="137"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="148"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="327"/>
        <source>About Sailcut CAD</source>
        <translation>Über Sailcut CAD</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="150"/>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="151"/>
        <source>About &amp;Sailcut CAD</source>
        <translation>Über &amp;Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="138"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="130"/>
        <source>Open &amp;recent</source>
        <translation>Zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation type="obsolete">E&amp;xport 3D-Segel</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation type="obsolete">&amp;Carlson Plotter</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="149"/>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Sailcut CAD &amp;Handbuch</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation type="obsolete">schattierte Ansicht</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation type="obsolete">Ansicht als Drahtmodell</translation>
    </message>
    <message>
        <source>development</source>
        <translation type="obsolete">Entwicklung</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation type="obsolete">neu erstelltes Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="208"/>
        <source>loaded &apos;%1&apos;</source>
        <translation>geladen &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="213"/>
        <source>error loading &apos;%1&apos;</source>
        <translation>Fehler beim Laden von &apos;%1&apos; </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="487"/>
        <source>wrote &apos;%1&apos;</source>
        <translation>gespeichert &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Fehler beim Drucken der Entwicklungsansicht</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Fehler beim drucken der Zeichnung</translation>
    </message>
    <message>
        <source>data</source>
        <translation type="obsolete">Daten</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation type="obsolete">Zeichnung</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">Dr&amp;ucken</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Segeltyp</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Großsegel</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fock</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Segelschnitt</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Kreuzschnitt</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horizontalschnitt</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Radialschnitt</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Twist-Foot Schnitt</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Vertikalschnitt</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Gehrungsschnitt</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete"> Segmente,   </translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Rigg </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Bootslänge LüA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Segelhalsposition X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Segelhalshöhe Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Segelabmessungen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Länge des Vorlieks</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Länge der Gaffel</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Länge des Unterlieks</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Länge des Achterlieks</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Vorliek-Bogen</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel-Bogen</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Achterliek-Bogen</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Unterliek-Bogen</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Position des Vorliekbogens</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Position des Gaffelbogens</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Position des Achterliekbogens</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Position des Unterliekbogens</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Eigenschaften des Segels</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Verwindungswinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Winkel der Segelbahn</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Bahnennähte und Säume</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Bahnbreite</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Nahtbreite</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">andere Saumbreiten</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Segelform</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Vorliegsfaktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Tiefe</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Achterlieksfaktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Oberes Profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Unteres Profil</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Neigung der Mastspur</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="obsolete">Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Tragfläche</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="obsolete">Radialkeile beginnend am Kopf und endend am Segelhals.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">°</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation type="obsolete">Export &amp;Entwicklung</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="obsolete">ins &amp;Hand-Plotterformat </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="125"/>
        <source>sail</source>
        <translation>Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="126"/>
        <source>hull</source>
        <translation>Rumpf</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="127"/>
        <source>rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="128"/>
        <source>boat</source>
        <translation>Boot</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="141"/>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="142"/>
        <source>&amp;Close</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="143"/>
        <source>Close &amp;All</source>
        <translation>Beenden &amp;alles</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="144"/>
        <source>&amp;Tile</source>
        <translation>&amp;Fliesen</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="145"/>
        <source>&amp;Cascade</source>
        <translation>&amp;Kaskade</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="200"/>
        <source>unknown document type &apos;%1&apos;</source>
        <translation>Fehler document type %1</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="444"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <location filename="../formmould.cpp" line="60"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="66"/>
        <source>Vertical repartition</source>
        <translation>Senkrechte Teilung</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="42"/>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="56"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="77"/>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="78"/>
        <source>Middle profile</source>
        <translation>Mittleres Profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="79"/>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
</context>
<context>
    <name>CFormPanelGroup</name>
    <message>
        <location filename="../formpanelgroup.cpp" line="56"/>
        <source>panels</source>
        <translation>Tafeln</translation>
    </message>
</context>
<context>
    <name>CFormPrint</name>
    <message>
        <location filename="../formprint.cpp" line="186"/>
        <source>&amp;Print</source>
        <translation>Dr&amp;ucken</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="189"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="165"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Rigg </translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Neu</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation type="obsolete">&amp;Definition des Segels</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation type="obsolete">3D &amp;Segel</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation type="obsolete">neues Segel &amp;hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="obsolete">Ö&amp;ffnen</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="obsolete">zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Speichern &amp;unter</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">Be&amp;enden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Datei</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="59"/>
        <source>rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="60"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
</context>
<context>
    <name>CFormRigDefBase</name>
    <message>
        <location filename="../formrigdefbase.ui" line="26"/>
        <source>Rig dimensions</source>
        <translation>Riggabmessungen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="64"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="51"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="291"/>
        <source>Spreaders</source>
        <translation>Salinge</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="338"/>
        <source>= SPNB</source>
        <translation>= SPNB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="345"/>
        <source>Number of spreaders</source>
        <translation>Anzahl der Sahlinge</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="361"/>
        <source>Spreader height</source>
        <translation>Saling-Höhe</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="385"/>
        <source>txt_SPH2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="407"/>
        <source>txt_SPH1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="429"/>
        <source>txt_SPH3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="445"/>
        <source>SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="458"/>
        <source>SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="471"/>
        <source>SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="487"/>
        <source>Spreader length</source>
        <translation>Saling-Länge</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="505"/>
        <source>SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="518"/>
        <source>txt_SPW3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="534"/>
        <source>SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="547"/>
        <source>txt_SPW1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="563"/>
        <source>SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="576"/>
        <source>txt_SPW2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="90"/>
        <source>Shrouds</source>
        <translation>Wanten</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="114"/>
        <source>Cap shroud base width</source>
        <translation>Basisweite der Oberwanten</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="133"/>
        <source>= CSH</source>
        <translation>= CSH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="152"/>
        <source>Lower shroud base width </source>
        <translation>Basisweite der Unterwanten</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="171"/>
        <source>txt_LSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="193"/>
        <source>txt_CSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="215"/>
        <source>= CSB</source>
        <translation>= CSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="234"/>
        <source>Cap shroud height</source>
        <translation>Oberwanten-Höhe</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="253"/>
        <source>txt_CSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="275"/>
        <source>= LSB</source>
        <translation>= LSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1384"/>
        <source>Fore triangle</source>
        <translation>Vorsegel-Dreieck</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1421"/>
        <source>txt_foreI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1431"/>
        <source>= I</source>
        <translation>= I</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1450"/>
        <source>txt_foreJ</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1460"/>
        <source>= J</source>
        <translation>= J</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1467"/>
        <source>Fore triangle base</source>
        <translation>Basis des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1474"/>
        <source>Fore triangle hoist</source>
        <translation>Höhe des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1091"/>
        <source>Mast</source>
        <translation>Mast</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1103"/>
        <source>Mast width</source>
        <translation>Mastbreite</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1110"/>
        <source>= MW</source>
        <translation>= MW</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1123"/>
        <source>txt_MW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1139"/>
        <source>txt_MC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1149"/>
        <source>= MC</source>
        <translation>= MC</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1156"/>
        <source>Mast cord</source>
        <translation>Mastschnur</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1166"/>
        <source>lbl_MRkD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1176"/>
        <source>= MRkD</source>
        <translation>= MRkD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1183"/>
        <source>Mast rake angle</source>
        <translation>Mastfallwinkel</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1202"/>
        <source>txt_MH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1212"/>
        <source>txt_MRnd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1238"/>
        <source>Mast rake</source>
        <translation>Mastfall</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1245"/>
        <source>= MRkM</source>
        <translation>= MRkM</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1264"/>
        <source>txt_MRkM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1286"/>
        <source>Mast height</source>
        <translation>Masthöhe</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1293"/>
        <source>= MH</source>
        <translation>= MH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1300"/>
        <source>= MRnd</source>
        <translation>= MRnd</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1319"/>
        <source>Mast round</source>
        <translation>Mast-Bogen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1326"/>
        <source>= MRndPos</source>
        <translation>= MRndPos</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1345"/>
        <source>Mast round position </source>
        <translation>Position des mastbogens </translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="604"/>
        <source>Mainsail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="631"/>
        <source>lbl_MS_LuffRP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="653"/>
        <source>@ </source>
        <translation>@</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="678"/>
        <source>lbl_MS_LuffR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="703"/>
        <source>lbl_MS_TackY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="725"/>
        <source>Y =</source>
        <translation>Y =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="750"/>
        <source>lbl_MS_TackX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="766"/>
        <source>X =</source>
        <translation>X =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="782"/>
        <source>Tack</source>
        <translation>Segelhals</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="820"/>
        <source>lbl_MS_LuffL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="836"/>
        <source>= MSL</source>
        <translation>= MSL</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="855"/>
        <source>Luff length </source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="874"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="896"/>
        <source>lbl_MS_Rake</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="912"/>
        <source>= MSR</source>
        <translation>= MSR</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="931"/>
        <source>Luff rake</source>
        <translation>Neigung der Vorliek</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="966"/>
        <source>Tack height </source>
        <translation>Segelhalshöhe</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="985"/>
        <source>txt_BAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1007"/>
        <source>= BAD</source>
        <translation>= BAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1027"/>
        <source>Head height</source>
        <translation>Höhe des Segelkopfes</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1040"/>
        <source>= HAD</source>
        <translation>= HAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1059"/>
        <source>txt_HAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="38"/>
        <source>Check</source>
        <translation>Prüfen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1544"/>
        <source>All dimensions are in millimeter and angles in degrees</source>
        <translation>Alle Massangaben sind in Millimeter und Grad </translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1490"/>
        <source>Description of rig</source>
        <translation>Beschreibung des Riggs</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1509"/>
        <source>Rig name</source>
        <translation>Name des Riggs</translation>
    </message>
</context>
<context>
    <name>CFormSail</name>
    <message>
        <location filename="../formsail.cpp" line="74"/>
        <source>sail</source>
        <translation>Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="77"/>
        <source>&amp;Print</source>
        <translation>Dr&amp;ucken</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="78"/>
        <source>data</source>
        <translation>Daten</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="79"/>
        <source>drawing</source>
        <translation>Zeichnung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="112"/>
        <source>development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="83"/>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xport 3D-Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="95"/>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="102"/>
        <source>to &amp;TXT sail</source>
        <translation>&amp;TXT Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="103"/>
        <source>to &amp;XML sail</source>
        <translation>&amp;XML Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="93"/>
        <source>Export &amp;development</source>
        <translation>Export &amp;Entwicklung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="94"/>
        <source>to &amp;Carlson plotter</source>
        <translation>&amp;Carlson Plotter</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="98"/>
        <source>to &amp;Hand-plotting format</source>
        <translation>ins &amp;Hand-Plotterformat </translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="106"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="107"/>
        <source>&amp;Mould</source>
        <translation>&amp;Form</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="108"/>
        <source>&amp;Patches</source>
        <translation>&amp;Verstärkungen</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Fehler beim Drucken der Entwicklungsansicht</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Fehler beim drucken der Zeichnung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="100"/>
        <source>to &amp;SVG</source>
        <translation>&amp;SVG</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="96"/>
        <source>to DXF (split)</source>
        <translation>DXF (geteilt)</translation>
    </message>
</context>
<context>
    <name>CFormSailDef</name>
    <message>
        <location filename="../formsaildef.cpp" line="1143"/>
        <source>Sail corners coordinates</source>
        <translation>Eckpunktkoordinaten des Segels</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1144"/>
        <source>tack</source>
        <translation>Segelhals</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1145"/>
        <source>clew</source>
        <translation>Schothorn</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1146"/>
        <source>head</source>
        <translation>Kopf</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1147"/>
        <source>peak</source>
        <translation>Nock</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="obsolete">IRC - Breite</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1152"/>
        <source>Sail width measurements </source>
        <translation>Segel breite</translation>
    </message>
</context>
<context>
    <name>CFormSailDefBase</name>
    <message>
        <location filename="../formsaildefbase.ui" line="25"/>
        <source>Sail definition</source>
        <translation>Definition des Segels</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="43"/>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1681"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="212"/>
        <source>Round position</source>
        <translation>Position des Bogens</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="146"/>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="165"/>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="191"/>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="231"/>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="238"/>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="354"/>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="245"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="252"/>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1269"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1450"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="361"/>
        <source>Gaff angle from luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="549"/>
        <source>Rig geometry</source>
        <translation>Geometrie der Takelage</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="662"/>
        <source>Fore triangle base  J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="636"/>
        <source>Tack height</source>
        <translation>Segelhalshöhe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="824"/>
        <source>Distance tack to stem</source>
        <translation>Abstand zwischen Segelhals und Vorsteven</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="576"/>
        <source>Main sail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="602"/>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="629"/>
        <source>Fore triangle hoist  I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="681"/>
        <source>Boat length LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation type="obsolete">Neigung der Mastspur</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1460"/>
        <source>Cloth</source>
        <translation>Material</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1626"/>
        <source>Seam width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1594"/>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="905"/>
        <source>Layout</source>
        <translation>Schnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1157"/>
        <source>Mitre cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="929"/>
        <source>Cross cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="948"/>
        <source>Twist foot</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1071"/>
        <source>Horizontal cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="967"/>
        <source>Number of sections</source>
        <translation>Anzahl der Segmente</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1027"/>
        <source>Number of radial gores</source>
        <translation>Anzahl der Radialkeile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1119"/>
        <source>Radial cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1090"/>
        <source>Vertical cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1205"/>
        <source>Sail shape</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1307"/>
        <source>Top depth</source>
        <translation>Obere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1329"/>
        <source>Mid depth</source>
        <translation>Mittlere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1351"/>
        <source>Foot depth</source>
        <translation>Untere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1411"/>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="885"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="869"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1610"/>
        <source>Leech hem</source>
        <translation>Achterlieksaum</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1516"/>
        <source>Other hems</source>
        <translation>Andere Säume</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1433"/>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="451"/>
        <source>Sail area</source>
        <translation>Segelfläche</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="444"/>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="898"/>
        <source>Compute</source>
        <translation>Berechnen</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation type="obsolete">Segel ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1049"/>
        <source>Number of luff gores</source>
        <translation>Anzahl der Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="583"/>
        <source>Dihedral angle</source>
        <translation>Öffnungswinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="615"/>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="496"/>
        <source>Sail identifier</source>
        <translation>Segelnummer</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="474"/>
        <source>m2</source>
        <translation>m2</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="530"/>
        <source>Sail name</source>
        <translation>Name von Segel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="643"/>
        <source>Luff rake</source>
        <translation>Neigung der Vorliek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1176"/>
        <source>Mitre cut 2</source>
        <translation>Gehrungsschnitt 2</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1532"/>
        <source>Foot hem</source>
        <translation>Unterlieksaum</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Information des Segels</translation>
    </message>
    <message>
        <source>file</source>
        <translation type="obsolete">Datei</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">Bezeichnung</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="obsolete">neu laden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Entfernen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="obsolete">Aktualisieren</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
<context>
    <name>CSailDataPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="44"/>
        <source>Sailcut CAD data sheet</source>
        <translation>Sailcut CAD Datenblatt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="50"/>
        <source>Mainsail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="53"/>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="59"/>
        <source>Sail type</source>
        <translation>Segeltyp</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="65"/>
        <source>Cross Cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="68"/>
        <source>Horizontal Cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="71"/>
        <source>Radial Cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="72"/>
        <source>sections</source>
        <translation> Segmente </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="73"/>
        <source>head gores</source>
        <translation>Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="74"/>
        <source>luff gores</source>
        <translation>Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="77"/>
        <source>Twist Foot Cut</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="80"/>
        <source>Vertical Cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="83"/>
        <source>Mitre Cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="86"/>
        <source>Mitre Cut 2</source>
        <translation>Gehrungsschnitt 2</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="89"/>
        <source>Sail layout</source>
        <translation>Segelschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="92"/>
        <source>Rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="93"/>
        <source>Boat LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Neigung der Mastspur</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="95"/>
        <source>Tack position X</source>
        <translation>Segelhalsposition X</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="96"/>
        <source>Tack height Y</source>
        <translation>Segelhalshöhe Y</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="97"/>
        <source>Fore triangle hoist I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="98"/>
        <source>Fore triangle base J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="101"/>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="102"/>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="103"/>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="104"/>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="105"/>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="106"/>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="109"/>
        <source>Shape of edges</source>
        <translation>Gestalt von Rändern</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="110"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="111"/>
        <source>Luff round position</source>
        <translation>Position des Vorliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="112"/>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="113"/>
        <source>Foot round position</source>
        <translation>Position des Unterliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="114"/>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="115"/>
        <source>Leech round position</source>
        <translation>Position des Achterliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="116"/>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="117"/>
        <source>Gaff round position</source>
        <translation>Position des Gaffelbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="120"/>
        <source>Sail settings</source>
        <translation>Eigenschaften des Segels</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="121"/>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="122"/>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="125"/>
        <source>Cloth seams and hems</source>
        <translation>Bahnennähte und Säume</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="126"/>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="127"/>
        <source>Seams width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="128"/>
        <source>Leech hem width</source>
        <translation>Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="129"/>
        <source>Foot hem width</source>
        <translation>Breite des Unterlieksaumes</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="130"/>
        <source>Other hems width</source>
        <translation>andere Saumbreiten</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="133"/>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Luff factor</source>
        <translation>Vorliegsfaktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Leech factor</source>
        <translation>Achterlieksfaktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="136"/>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="142"/>
        <source>Mid profile at h = </source>
        <translation>Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="148"/>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="94"/>
        <source>Luff rake</source>
        <translation>Neigung der Vorliek</translation>
    </message>
</context>
<context>
    <name>CSailDevelPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="190"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dieses System hat keine OpenGL Unterstützung.</translation>
    </message>
</context>
<context>
    <name>CSailDrawingPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="221"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation type="obsolete">Sailcut CAD Datenblatt</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Großsegel</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Fock</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Tragfläche</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">°</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Segeltyp</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Kreuzschnitt</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horizontalschnitt</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Radialschnitt</translation>
    </message>
    <message>
        <source>sections</source>
        <translation type="obsolete"> Segmente </translation>
    </message>
    <message>
        <source>head gores</source>
        <translation type="obsolete">Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation type="obsolete">Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Twist-Foot Schnitt</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Vertikalschnitt</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Gehrungsschnitt</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Segelschnitt</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Rigg </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Bootslänge LüA</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Neigung der Mastspur</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Segelhalsposition X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Segelhalshöhe Y</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Segelabmessungen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Länge des Vorlieks</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Länge des Unterlieks</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Länge des Achterlieks</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Länge der Gaffel</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Gestalt von Rändern</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Vorliek-Bogen</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Position des Vorliekbogens</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Unterliek-Bogen</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Position des Unterliekbogens</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Achterliek-Bogen</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Position des Achterliekbogens</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel-Bogen</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Position des Gaffelbogens</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Eigenschaften des Segels</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Verwindungswinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Winkel der Segelbahn</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Bahnennähte und Säume</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Bahnbreite</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Nahtbreite</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">andere Saumbreiten</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Segelform</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Vorliegsfaktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Tiefe</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Achterlieksfaktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Oberes Profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Unteres Profil</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <location filename="../sailviewer-panel.cpp" line="137"/>
        <source>Display parameters</source>
        <translation>Anzeigeparameter</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="138"/>
        <source>elevation</source>
        <translation>vertikal</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="139"/>
        <source>azimuth</source>
        <translation>horizontal</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="141"/>
        <source>Controls</source>
        <translation>Darstellung</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="142"/>
        <source>Reset view</source>
        <translation>Ansicht zurücksetzen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="145"/>
        <source>Labeling</source>
        <translation>Segelzeichen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="147"/>
        <source>Zoom in</source>
        <translation>Einzoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="148"/>
        <source>Zoom out</source>
        <translation>Auszoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="186"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>CSailViewerTabs</name>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="60"/>
        <source>shaded view</source>
        <translation>schattierte Ansicht</translation>
    </message>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="62"/>
        <source>wireframe view</source>
        <translation>Ansicht als Drahtmodell</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <location filename="../widgetprofile.cpp" line="245"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="243"/>
        <source>Luff shape</source>
        <translation>Vorliekform</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="244"/>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="246"/>
        <source>Leech shape</source>
        <translation>Achterliekform</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="250"/>
        <source>degrees</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="249"/>
        <source>cord</source>
        <translation>Schnur</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
</TS>
